"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
/**
 * Hook that indicates if a certain amount of time has passed since the component was mounted.
 * @param delay - The delay time in ms, defaults to 200
 *
 * @example
 * function Loading() {
 *		const past_delay = usePastDelay();
 *		if (! past_delay) return null
 *		return <div>Loading ...</div>;
 * }
 */
function usePastDelay(delay = 200) {
    const [past_delay, setPastDelay] = (0, react_1.useState)(false);
    (0, react_1.useEffect)(() => {
        const timeout = setTimeout(() => setPastDelay(true), delay);
        return () => {
            clearTimeout(timeout);
        };
    }, [delay]);
    return past_delay;
}
exports.default = usePastDelay;
